import os
from os import listdir
from PIL import Image
import PyPDF2
from PyPDF2 import PdfFileMerger

def MakePdf(Path,NamePdf):
    try:
        imagenes = []
        images_list = []
        listarImagenes  = listdir(Path)
        for list in listarImagenes:  
            a = Path +"/"+ list
            imagenes.append(a)
        #print(imagenes)
        for f in imagenes:
            try:
                #print(f)
                images_list.append((Image.open(f)).convert('RGB'))
            except IOError as er:
                return er
        images_list[0].save(NamePdf, save_all=True, append_images=images_list[1:])
        return "./"+NamePdf
    except Exception as err:
        return err


#Merge pdf files
def mergerPDf(Path,NamePdf):
    
    try:
        PDFS = []
        listarPDf  = listdir(Path)
        for list in listarPDf:  
            a = Path +"/"+ list
            PDFS .append(a)
        pdfs = PDFS
        merger = PdfFileMerger()
        for pdf in pdfs:
            merger.append(pdf)
        merger.write(NamePdf)
        merger.close()
        return "./"+NamePdf
    except Exception as err:
        return err


import setuptools
from setuptools import find_packages, setup
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

requires =["setuptools>=61.0.0", "wheel","pillow","PyPDF2"]

setuptools.setup(
    name="MakePdfEasily", 
    version="0.0.25",
    author="MakePdfEasily",
    author_email="ali0088552211@gmail.com",
    description="MakePdfEasily",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/AliAdnanc7/MakePdfEasily",
    project_urls={
        "Bug Tracker": "https://github.com/AliAdnanc7/MakePdfEasily/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    
    packages=['src'],
    package_data={'src': ['MakePdfEasily.py']},
    python_requires=">=3.6",
    install_requires=requires,
)